Imports System.Windows.Forms
Imports System.Text

Imports Infragistics.Win.UltraWinDataSource
Imports Infragistics.Win.UltraWinGrid
Imports Infragistics.Win

Public Class dlgImportContacts
    Inherits System.Windows.Forms.Form

    Private m_ContactsSelected As Integer = 10
    Private m_ContactsLoaded As Integer = 0
    Private m_CompaniesSelected As Integer = 0

    Friend Delegate Sub GetAllContacts()
    Friend Delegate Sub GetAllCompanies()

    Friend Delegate Sub SetTextCallback(ByVal [text] As String)
    Friend Delegate Sub SetCompaniesText(ByVal [text] As String)
    Friend Delegate Sub SetContactsText(ByVal [text]() As String)
    Friend Delegate Sub LoadOutlookUGMsgBox()

#Region "Constructor"

    Public Sub New()

        ' This call is required by the Windows Form Designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.

    End Sub
#End Region

#Region "Common Code and Windows Events"

    Private Sub SetText(ByVal [text] As String)

        If Me.ulSelFolder.InvokeRequired Then
            Me.Invoke(New SetTextCallback(AddressOf SetText), New Object() {[text]})
        Else
            Me.ulSelFolder.Text = [text]
        End If
    End Sub

    Private Sub ChgCompaniesText(ByVal text As String)

        If Me.ugCompanies.InvokeRequired Then
            Me.Invoke(New SetCompaniesText(AddressOf ChgCompaniesText), New Object() {text})
        Else
            Me.ugCompanies.Text = "Companies (Records Returned = " + text + " )"
        End If
    End Sub

    Private Sub ChgContactsText(ByVal text() As String)

        If Me.ugContacts.InvokeRequired Then
            Me.Invoke(New SetContactsText(AddressOf ChgContactsText), New Object() {text}(0))
        Else
            Me.ugContacts.Text = "Contacts (Records Returned = " + text(0) + " )" + _
                            Environment.NewLine() + _
                                "              (Records Loaded    = " + text(1) + " )"
            m_ContactsSelected = CInt(text(0))
        End If
    End Sub

    Private Sub ShowOutlookUGMsgBox()

        If Me.ugContacts.InvokeRequired Then
            Me.Invoke(New LoadOutlookUGMsgBox(AddressOf ShowOutlookUGMsgBox))
        Else
            MsgBox("The folder that you selected in not the default contacts " & vbCrLf & _
                        "folder.  To use the folder that you selected, the Outlook " & vbCrLf & _
                        "application must also be executing.  Start the Outlook application " & vbCrLf & _
                        "and then reselect the folder.", _
                        MsgBoxStyle.Information, "Select a Contacts Folder Error")
        End If
    End Sub

    Private Sub SetGlobalCheckState(ByVal check As Boolean)
        Dim mainBand As UltraGridBand = ugContacts.DisplayLayout.Bands(0)
        mainBand.Columns("Contacts").SetHeaderCheckedState(ugContacts.Rows, check)

        If check Then
            m_ContactsSelected = ugContacts.Rows.Count
        Else
            m_ContactsSelected = 0
        End If

        Import_Contacts_Enabled_Status()

        For K As Integer = 1 To 3

            Dim ColKey As String
            Dim RowKey As String

            Select Case K
                Case 1
                    ColKey = "Addresses"
                    RowKey = "Address"
                Case 2
                    ColKey = "Phones"
                    RowKey = "Phones"
                Case Else
                    ColKey = "Emails"
                    RowKey = "Emails"
            End Select

            Dim childBand As UltraGridBand = ugContacts.DisplayLayout.Bands(ColKey)
            Dim childBoolColumn As UltraGridColumn = childBand.Columns(RowKey)
            Dim boolSynchronization As HeaderCheckBoxSynchronization = childBoolColumn.Header.CheckBoxSynchronizationResolved

            If boolSynchronization = HeaderCheckBoxSynchronization.RowsCollection Then
                For Each row As UltraGridRow In ugContacts.Rows
                    Dim childRows As RowsCollection = row.ChildBands(ColKey).Rows
                    childBoolColumn.SetHeaderCheckedState(childRows, check)
                Next
            ElseIf boolSynchronization = HeaderCheckBoxSynchronization.Band Then
                childBoolColumn.SetHeaderCheckedState(Nothing, check)
            End If
        Next
    End Sub

    Private Sub Import_Contacts_Enabled_Status()

        If m_ContactsSelected > 0 And m_CompaniesSelected = 1 Then
            Me.button_Import_Contacts.Enabled = True
        Else
            Me.button_Import_Contacts.Enabled = False
        End If

    End Sub

    Private Sub dlgImportContacts_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load

        Dim ldContacts As New GetAllContacts(AddressOf control_UI_Loading)
        ldContacts.BeginInvoke(Nothing, Nothing)

        load_Companies_Control()

    End Sub
#End Region

#Region "Buttons"

    Private Sub button_OK_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_OK.Click

        Me.DialogResult = System.Windows.Forms.DialogResult.OK
        Me.Close()

    End Sub

    Private Sub button_Cancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Cancel.Click

        Me.DialogResult = System.Windows.Forms.DialogResult.Cancel
        Me.Close()

    End Sub

    Private Sub button_Select_Folder_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Select_Folder.Click
        MyBase.Cursor = Cursors.WaitCursor

        control_UI_Loading()

        MyBase.Cursor = Cursors.Default
    End Sub

    Private Sub button_Reload_Companies_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles button_Reload_Companies.Click

        MyBase.Cursor = Cursors.WaitCursor

        Load_Companies()

        MyBase.Cursor = Cursors.Default

    End Sub

    Private Sub button_Show_Company_Filterrow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Show_Company_Filterrow.Click

        If ugCompanies.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.Default Or _
            ugCompanies.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.False Then
            ugCompanies.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.True
        Else
            ugCompanies.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.False
        End If

    End Sub

    Private Sub button_Import_Contacts_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Import_Contacts.Click

        getSelectedContacts()

    End Sub

    Private Sub button_Show_Contacts_Filterrow_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Show_Contacts_Filterrow.Click

        If ugContacts.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.Default Or _
            ugContacts.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.False Then
            ugContacts.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.True
        Else
            ugContacts.DisplayLayout.Override.AllowRowFiltering = DefaultableBoolean.False
        End If

    End Sub

    Private Sub button_Check_Uncheck_Boxes_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles button_Check_Uncheck_Boxes.Click

        If button_Check_Uncheck_Boxes.Text = "Check All" Then
            SetGlobalCheckState(True)
            button_Check_Uncheck_Boxes.Text = "UnCheck All"
        Else
            SetGlobalCheckState(False)
            button_Check_Uncheck_Boxes.Text = "Check All"
        End If

    End Sub

#End Region

#Region "Select Folder and Load Outlook Contact Info Into Grid"

    Private Sub control_UI_Loading()

        Dim Text(1) As String

        ugContacts.DataSource = udsContacts

        Dim band As UltraGridBand = ugContacts.DisplayLayout.Bands("Band 0")
        band.Columns("FullName").SortIndicator = SortIndicator.Ascending
        band.SortedColumns.Clear()
        band.SortedColumns.Add("FullName", False, False)

        Text(0) = Format(10, "###,##0")
        Text(1) = Format(0, "###,##0")

        ChgContactsText(Text)

    End Sub

#End Region

#Region "Load Companies from SQL Server into Control"

    Private Sub load_Companies_Control()

        Dim ldCompanies As New GetAllCompanies(AddressOf Load_Companies)
        ldCompanies.BeginInvoke(Nothing, Nothing)

    End Sub

    Private Sub load_Companies()

        Dim tabCoInfo As New CompanyInfo.CompanyDataDataTable

        ugCompanies.DataSource = tabCoInfo

        ChgCompaniesText(Format(ugCompanies.Rows.Count, "###,##0"))

    End Sub

#End Region

#Region "Extract and Load Contacts into DB"

    Private Sub getSelectedContacts()

    End Sub

#End Region

#Region "ugCompanies Events"

    Private Sub ugCompanies_AfterSelectChange(ByVal sender As Object, ByVal e As Infragistics.Win.UltraWinGrid.AfterSelectChangeEventArgs) Handles ugCompanies.AfterSelectChange

    End Sub

#End Region

#Region "ugContact Events"

    Private Sub ugContacts_AfterHeaderCheckStateChanged(ByVal sender As Object, ByVal e As Infragistics.Win.UltraWinGrid.AfterHeaderCheckStateChangedEventArgs) Handles ugContacts.AfterHeaderCheckStateChanged

    End Sub

    Private Sub ugContacts_InitializeLayout(ByVal sender As System.Object, ByVal e As Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs) Handles ugContacts.InitializeLayout

        Dim band As UltraGridBand = e.Layout.Bands(0)

        band.ColumnFilters("WasSelected").FilterConditions.Clear()
        band.ColumnFilters("WasSelected").FilterConditions.Add(FilterComparisionOperator.Contains, False)

        UIElementDrawParams.CheckBoxGlyphInfo = UIElementDrawParams.Office2007CheckBoxGlyphInfo

    End Sub

    Private Sub ugContacts_CellChange(ByVal sender As Object, ByVal e As CellEventArgs) Handles ugContacts.CellChange

    End Sub

    Private Sub ugContacts_BeforeRowExpanded(ByVal sender As Object, ByVal e As Infragistics.Win.UltraWinGrid.CancelableRowEventArgs) Handles ugContacts.BeforeRowExpanded
    End Sub

#End Region

End Class
